@@ -2,7 +2,6 @@
 
 from collections import namedtuple
 from os.path import join
-from threading import RLock
 from weakref import WeakValueDictionary
 
 from ..constants import ROOT
@@ -11,8 +10,6 @@ FOLDER: str = join(ROOT, "logs")
 
 INSTANCES = WeakValueDictionary()
 
-RECURSIVE_THREAD_LOCK = RLock()
-
 ROW = namedtuple("ROW", ["time", "level", "file", "line", "code", "message"])
 FRAME = namedtuple("FRAME", ["file", "line", "code"])
 TRACEBACK = namedtuple("TRACEBACK", ["file", "line", "code", "message"])
